@@ -6,18 +6,18 @@ from user_media.models import UserMediaImage
 from user_media.tests.test_app.models import DummyModel, DummyGallery
 
 
-class DummyModelFactory(factory.Factory):
+class DummyModelFactory(factory.DjangoModelFactory):
     FACTORY_FOR = DummyModel
     user = factory.SubFactory(UserFactory)
 
 
-class DummyGalleryFactory(factory.Factory):
+class DummyGalleryFactory(factory.DjangoModelFactory):
     """Factory for the ``DummyGallery`` model."""
     FACTORY_FOR = DummyGallery
     user_connection = factory.SubFactory(UserFactory)
 
 
-class UserMediaImageFactory(factory.Factory):
+class UserMediaImageFactory(factory.DjangoModelFactory):
     """Factory for ``UserMediaImage`` objects."""
     FACTORY_FOR = UserMediaImage
 
