@@ -2,13 +2,16 @@
 Dummy models needed for the tests of the `django-user-media` application.
 
 """
+from django.conf import settings
 from django.contrib.contenttypes import generic
 from django.db import models
 
 
 class DummyGallery(models.Model):
     """Model to simulate a gallery."""
-    user_connection = models.ForeignKey('auth.User')
+    user_connection = models.ForeignKey(
+        getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
+    )
 
     images = generic.GenericRelation(
         'user_media.UserMediaImage',
@@ -38,7 +41,7 @@ class DummyModel(models.Model):
     tied to this content object.
 
     """
-    user = models.ForeignKey('auth.User')
+    user = models.ForeignKey(getattr(settings, 'AUTH_USER_MODEL', 'auth.User'))
 
     images = generic.GenericRelation(
         'user_media.UserMediaImage',
